@@ -18,7 +18,6 @@
 #include <KConfig>
 #include <KConfigSkeleton>
 
-#include <QDebug>
 #include <QString>
 
 /* Includes to handle various types of dictionaries
@@ -27,6 +26,8 @@ IMPORTANT: To add a dictionary type, add the header file here and add it to the
 #include "DictEdict/dictfileedict.h"
 #include "DictKanjidic/dictfilekanjidic.h"
 
+using namespace Qt::StringLiterals;
+
 class DictionaryManager::Private
 {
 public:
@@ -210,8 +211,11 @@ QMap<QString, DictionaryPreferenceDialog *> DictionaryManager::generatePreferenc
         DictFile *tempDictFile = makeDictFile(dictType);
         DictionaryPreferenceDialog *newDialog = tempDictFile->preferencesWidget(config, parent);
 
-        if (newDialog == nullptr)
+        if (newDialog == nullptr) {
+            delete tempDictFile;
             continue;
+        }
+
         result.insert(dictType, newDialog);
         delete tempDictFile;
     }
@@ -293,7 +297,7 @@ void DictionaryManager::loadDictSettings(const QString &dictName, KConfigSkeleto
 {
     DictFile *dict = this->makeDictFile(dictName);
     if (dict != nullptr) {
-        config->setCurrentGroup("dicts_" + dictName.toLower());
+        config->setCurrentGroup("dicts_"_L1 + dictName.toLower());
         dict->loadSettings(config);
         delete dict;
     }
@@ -301,7 +305,7 @@ void DictionaryManager::loadDictSettings(const QString &dictName, KConfigSkeleto
 
 void DictionaryManager::loadSettings(const KConfig &config)
 {
-    Q_UNUSED(config);
+    Q_UNUSED(config)
     // TODO
 }
 
